#[repr(C)]pub struct ControllerOpenSessionRequest {
pub session: ServerEnd<Device, Channel>,
}Fields
session: ServerEnd<Device, Channel>Trait Implementations
Sourceimpl Debug for ControllerOpenSessionRequest
impl Debug for ControllerOpenSessionRequest
Sourceimpl<___E> Encode<ControllerOpenSessionRequest, ___E> for ControllerOpenSessionRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ControllerOpenSessionRequest, ___E> for ControllerOpenSessionRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ControllerOpenSessionRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ControllerOpenSessionRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ControllerOpenSessionRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ControllerOpenSessionRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ControllerOpenSessionRequest>, ___E> for ControllerOpenSessionRequestwhere
___E: Encoder + ?Sized,
ControllerOpenSessionRequest: Encode<ControllerOpenSessionRequest, ___E>,
impl<___E> EncodeOption<Box<'static, ControllerOpenSessionRequest>, ___E> for ControllerOpenSessionRequestwhere
___E: Encoder + ?Sized,
ControllerOpenSessionRequest: Encode<ControllerOpenSessionRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ControllerOpenSessionRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ControllerOpenSessionRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ControllerOpenSessionRequest> for ControllerOpenSessionRequest
impl FromWire<ControllerOpenSessionRequest> for ControllerOpenSessionRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ControllerOpenSessionRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ControllerOpenSessionRequest, Self>
Sourcefn from_wire(wire: ControllerOpenSessionRequest) -> Self
fn from_wire(wire: ControllerOpenSessionRequest) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ControllerOpenSessionRequest
impl PartialEq for ControllerOpenSessionRequest
Sourcefn eq(&self, other: &ControllerOpenSessionRequest) -> bool
fn eq(&self, other: &ControllerOpenSessionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ControllerOpenSessionRequest