#[repr(C)]pub struct DeviceAssertCsResponse {
pub status: Status,
}Fields
status: StatusTrait Implementations
Sourceimpl Clone for DeviceAssertCsResponse
impl Clone for DeviceAssertCsResponse
Sourcefn clone(&self) -> DeviceAssertCsResponse
fn clone(&self) -> DeviceAssertCsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceAssertCsResponse
impl Debug for DeviceAssertCsResponse
Sourceimpl<'a, ___E> Encode<DeviceAssertCsResponse, ___E> for &'a DeviceAssertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceAssertCsResponse, ___E> for &'a DeviceAssertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceAssertCsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceAssertCsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceAssertCsResponse, ___E> for DeviceAssertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceAssertCsResponse, ___E> for DeviceAssertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceAssertCsResponse, DeviceAssertCsResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceAssertCsResponse, DeviceAssertCsResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceAssertCsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceAssertCsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceAssertCsResponse>, ___E> for &'a DeviceAssertCsResponse
impl<'a, ___E> EncodeOption<Box<'static, DeviceAssertCsResponse>, ___E> for &'a DeviceAssertCsResponse
Sourcefn encode_option(
this: Option<&'a DeviceAssertCsResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceAssertCsResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceAssertCsResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceAssertCsResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceAssertCsResponse>, ___E> for DeviceAssertCsResponse
impl<___E> EncodeOption<Box<'static, DeviceAssertCsResponse>, ___E> for DeviceAssertCsResponse
Sourcefn encode_option(
this: Option<DeviceAssertCsResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceAssertCsResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceAssertCsResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceAssertCsResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceAssertCsResponse> for DeviceAssertCsResponse
impl FromWire<DeviceAssertCsResponse> for DeviceAssertCsResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceAssertCsResponse, DeviceAssertCsResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceAssertCsResponse, DeviceAssertCsResponse>
Sourcefn from_wire(wire: DeviceAssertCsResponse) -> DeviceAssertCsResponse
fn from_wire(wire: DeviceAssertCsResponse) -> DeviceAssertCsResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceAssertCsResponse> for DeviceAssertCsResponse
impl FromWireRef<DeviceAssertCsResponse> for DeviceAssertCsResponse
Sourcefn from_wire_ref(wire: &DeviceAssertCsResponse) -> DeviceAssertCsResponse
fn from_wire_ref(wire: &DeviceAssertCsResponse) -> DeviceAssertCsResponse
Converts the given reference to this type.
Sourceimpl Hash for DeviceAssertCsResponse
impl Hash for DeviceAssertCsResponse
Sourceimpl Ord for DeviceAssertCsResponse
impl Ord for DeviceAssertCsResponse
Sourcefn cmp(&self, other: &DeviceAssertCsResponse) -> Ordering
fn cmp(&self, other: &DeviceAssertCsResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceAssertCsResponse
impl PartialEq for DeviceAssertCsResponse
Sourcefn eq(&self, other: &DeviceAssertCsResponse) -> bool
fn eq(&self, other: &DeviceAssertCsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceAssertCsResponse
impl PartialOrd for DeviceAssertCsResponse
impl Copy for DeviceAssertCsResponse
impl Eq for DeviceAssertCsResponse
impl StructuralPartialEq for DeviceAssertCsResponse