pub struct DeviceReceiveVectorResponse {
pub status: Status,
pub data: Vec<u8>,
}Fields
status: Statusdata: Vec<u8>Trait Implementations
Sourceimpl Clone for DeviceReceiveVectorResponse
impl Clone for DeviceReceiveVectorResponse
Sourcefn clone(&self) -> DeviceReceiveVectorResponse
fn clone(&self) -> DeviceReceiveVectorResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceReceiveVectorResponse
impl Debug for DeviceReceiveVectorResponse
Sourceimpl<'a, ___E> Encode<DeviceReceiveVectorResponse<'static>, ___E> for &'a DeviceReceiveVectorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<DeviceReceiveVectorResponse<'static>, ___E> for &'a DeviceReceiveVectorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReceiveVectorResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReceiveVectorResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReceiveVectorResponse<'static>, ___E> for DeviceReceiveVectorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<DeviceReceiveVectorResponse<'static>, ___E> for DeviceReceiveVectorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReceiveVectorResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReceiveVectorResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceReceiveVectorResponse<'static>>, ___E> for &'a DeviceReceiveVectorResponsewhere
___E: Encoder + ?Sized,
&'a DeviceReceiveVectorResponse: Encode<DeviceReceiveVectorResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceReceiveVectorResponse<'static>>, ___E> for &'a DeviceReceiveVectorResponsewhere
___E: Encoder + ?Sized,
&'a DeviceReceiveVectorResponse: Encode<DeviceReceiveVectorResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceReceiveVectorResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReceiveVectorResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceReceiveVectorResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReceiveVectorResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceReceiveVectorResponse<'static>>, ___E> for DeviceReceiveVectorResponsewhere
___E: Encoder + ?Sized,
DeviceReceiveVectorResponse: Encode<DeviceReceiveVectorResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceReceiveVectorResponse<'static>>, ___E> for DeviceReceiveVectorResponsewhere
___E: Encoder + ?Sized,
DeviceReceiveVectorResponse: Encode<DeviceReceiveVectorResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<DeviceReceiveVectorResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReceiveVectorResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceReceiveVectorResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReceiveVectorResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceReceiveVectorResponse<'de>> for DeviceReceiveVectorResponse
impl<'de> FromWire<DeviceReceiveVectorResponse<'de>> for DeviceReceiveVectorResponse
Sourcefn from_wire(
wire: DeviceReceiveVectorResponse<'de>,
) -> DeviceReceiveVectorResponse
fn from_wire( wire: DeviceReceiveVectorResponse<'de>, ) -> DeviceReceiveVectorResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceReceiveVectorResponse<'de>> for DeviceReceiveVectorResponse
impl<'de> FromWireRef<DeviceReceiveVectorResponse<'de>> for DeviceReceiveVectorResponse
Sourcefn from_wire_ref(
wire: &DeviceReceiveVectorResponse<'de>,
) -> DeviceReceiveVectorResponse
fn from_wire_ref( wire: &DeviceReceiveVectorResponse<'de>, ) -> DeviceReceiveVectorResponse
Converts the given reference to this type.
Sourceimpl Hash for DeviceReceiveVectorResponse
impl Hash for DeviceReceiveVectorResponse
Sourceimpl Ord for DeviceReceiveVectorResponse
impl Ord for DeviceReceiveVectorResponse
Sourcefn cmp(&self, other: &DeviceReceiveVectorResponse) -> Ordering
fn cmp(&self, other: &DeviceReceiveVectorResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceReceiveVectorResponse
impl PartialEq for DeviceReceiveVectorResponse
Sourcefn eq(&self, other: &DeviceReceiveVectorResponse) -> bool
fn eq(&self, other: &DeviceReceiveVectorResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceReceiveVectorResponse
impl PartialOrd for DeviceReceiveVectorResponse
impl Eq for DeviceReceiveVectorResponse
impl StructuralPartialEq for DeviceReceiveVectorResponse