#[repr(C)]pub struct ControllerOpenSessionRequest {
pub session: ServerEnd<Device, Channel>,
}Expand description
The wire type corresponding to ControllerOpenSessionRequest.
Fields
session: ServerEnd<Device, Channel>Trait Implementations
Sourceimpl Constrained for ControllerOpenSessionRequest
impl Constrained for ControllerOpenSessionRequest
Sourceimpl Debug for ControllerOpenSessionRequest
impl Debug for ControllerOpenSessionRequest
Sourceimpl<___D> Decode<___D> for ControllerOpenSessionRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ControllerOpenSessionRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ControllerOpenSessionRequest, ___E> for ControllerOpenSessionRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ControllerOpenSessionRequest, ___E> for ControllerOpenSessionRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ControllerOpenSessionRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ControllerOpenSessionRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ControllerOpenSessionRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ControllerOpenSessionRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ControllerOpenSessionRequest, ___E> for ControllerOpenSessionRequest<T0>
impl<___E, T0> Encode<ControllerOpenSessionRequest, ___E> for ControllerOpenSessionRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ControllerOpenSessionRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ControllerOpenSessionRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ControllerOpenSessionRequest> for ControllerOpenSessionRequest
impl FromWire<ControllerOpenSessionRequest> for ControllerOpenSessionRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ControllerOpenSessionRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ControllerOpenSessionRequest, Self>
Sourcefn from_wire(wire: ControllerOpenSessionRequest) -> Self
fn from_wire(wire: ControllerOpenSessionRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ControllerOpenSessionRequest
impl IntoNatural for ControllerOpenSessionRequest
Sourcetype Natural = ControllerOpenSessionRequest
type Natural = ControllerOpenSessionRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ControllerOpenSessionRequest
impl Wire for ControllerOpenSessionRequest
Sourcetype Narrowed<'de> = ControllerOpenSessionRequest
type Narrowed<'de> = ControllerOpenSessionRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.