#[repr(C)]pub struct DeviceAssertCsResponse {
pub status: Status,
}Expand description
The wire type corresponding to DeviceAssertCsResponse.
Fields
status: StatusTrait Implementations
Sourceimpl Clone for DeviceAssertCsResponse
impl Clone for DeviceAssertCsResponse
Sourcefn clone(&self) -> DeviceAssertCsResponse
fn clone(&self) -> DeviceAssertCsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceAssertCsResponse
impl Constrained for DeviceAssertCsResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceAssertCsResponse>,
_: <DeviceAssertCsResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceAssertCsResponse>, _: <DeviceAssertCsResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceAssertCsResponse
impl Debug for DeviceAssertCsResponse
Sourceimpl<___D> Decode<___D> for DeviceAssertCsResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceAssertCsResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceAssertCsResponse, ___E> for &'a DeviceAssertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceAssertCsResponse, ___E> for &'a DeviceAssertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceAssertCsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceAssertCsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceAssertCsResponse, ___E> for DeviceAssertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceAssertCsResponse, ___E> for DeviceAssertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceAssertCsResponse, DeviceAssertCsResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceAssertCsResponse, DeviceAssertCsResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceAssertCsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceAssertCsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceAssertCsResponse, ___E> for DeviceAssertCsResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Status, ___E>,
impl<___E, T0> Encode<DeviceAssertCsResponse, ___E> for DeviceAssertCsResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Status, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceAssertCsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceAssertCsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceAssertCsResponse> for DeviceAssertCsResponse
impl FromWire<DeviceAssertCsResponse> for DeviceAssertCsResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceAssertCsResponse, DeviceAssertCsResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceAssertCsResponse, DeviceAssertCsResponse>
Sourcefn from_wire(wire: DeviceAssertCsResponse) -> DeviceAssertCsResponse
fn from_wire(wire: DeviceAssertCsResponse) -> DeviceAssertCsResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceAssertCsResponse> for DeviceAssertCsResponse
impl FromWireRef<DeviceAssertCsResponse> for DeviceAssertCsResponse
Sourcefn from_wire_ref(wire: &DeviceAssertCsResponse) -> DeviceAssertCsResponse
fn from_wire_ref(wire: &DeviceAssertCsResponse) -> DeviceAssertCsResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceAssertCsResponse
impl IntoNatural for DeviceAssertCsResponse
Sourcetype Natural = DeviceAssertCsResponse
type Natural = DeviceAssertCsResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceAssertCsResponse
impl Wire for DeviceAssertCsResponse
Sourcetype Narrowed<'de> = DeviceAssertCsResponse
type Narrowed<'de> = DeviceAssertCsResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceAssertCsResponse>)
fn zero_padding(out_: &mut MaybeUninit<DeviceAssertCsResponse>)
Writes zeroes to the padding for this type, if any.