#[repr(C)]pub struct DeviceDeassertCsResponse {
pub status: Status,
}Expand description
The wire type corresponding to DeviceDeassertCsResponse.
Fields
status: StatusTrait Implementations
Sourceimpl Clone for DeviceDeassertCsResponse
impl Clone for DeviceDeassertCsResponse
Sourcefn clone(&self) -> DeviceDeassertCsResponse
fn clone(&self) -> DeviceDeassertCsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceDeassertCsResponse
impl Constrained for DeviceDeassertCsResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceDeassertCsResponse>,
_: <DeviceDeassertCsResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceDeassertCsResponse>, _: <DeviceDeassertCsResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceDeassertCsResponse
impl Debug for DeviceDeassertCsResponse
Sourceimpl<___D> Decode<___D> for DeviceDeassertCsResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceDeassertCsResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceDeassertCsResponse, ___E> for &'a DeviceDeassertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceDeassertCsResponse, ___E> for &'a DeviceDeassertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceDeassertCsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceDeassertCsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceDeassertCsResponse, ___E> for DeviceDeassertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceDeassertCsResponse, ___E> for DeviceDeassertCsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceDeassertCsResponse, DeviceDeassertCsResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceDeassertCsResponse, DeviceDeassertCsResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceDeassertCsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceDeassertCsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceDeassertCsResponse, ___E> for DeviceDeassertCsResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Status, ___E>,
impl<___E, T0> Encode<DeviceDeassertCsResponse, ___E> for DeviceDeassertCsResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Status, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceDeassertCsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceDeassertCsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceDeassertCsResponse> for DeviceDeassertCsResponse
impl FromWire<DeviceDeassertCsResponse> for DeviceDeassertCsResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceDeassertCsResponse, DeviceDeassertCsResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceDeassertCsResponse, DeviceDeassertCsResponse>
Sourcefn from_wire(wire: DeviceDeassertCsResponse) -> DeviceDeassertCsResponse
fn from_wire(wire: DeviceDeassertCsResponse) -> DeviceDeassertCsResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceDeassertCsResponse> for DeviceDeassertCsResponse
impl FromWireRef<DeviceDeassertCsResponse> for DeviceDeassertCsResponse
Sourcefn from_wire_ref(wire: &DeviceDeassertCsResponse) -> DeviceDeassertCsResponse
fn from_wire_ref(wire: &DeviceDeassertCsResponse) -> DeviceDeassertCsResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceDeassertCsResponse
impl IntoNatural for DeviceDeassertCsResponse
Sourcetype Natural = DeviceDeassertCsResponse
type Natural = DeviceDeassertCsResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceDeassertCsResponse
impl Wire for DeviceDeassertCsResponse
Sourcetype Narrowed<'de> = DeviceDeassertCsResponse
type Narrowed<'de> = DeviceDeassertCsResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceDeassertCsResponse>)
fn zero_padding(out_: &mut MaybeUninit<DeviceDeassertCsResponse>)
Writes zeroes to the padding for this type, if any.