#[repr(C)]pub struct TestConnectSpiLoopbackRequest {
pub server: ServerEnd<Device, Channel>,
}Expand description
The wire type corresponding to TestConnectSpiLoopbackRequest.
Fields
server: ServerEnd<Device, Channel>Trait Implementations
Sourceimpl Constrained for TestConnectSpiLoopbackRequest
impl Constrained for TestConnectSpiLoopbackRequest
Sourceimpl<___D> Decode<___D> for TestConnectSpiLoopbackRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for TestConnectSpiLoopbackRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<TestConnectSpiLoopbackRequest, ___E> for TestConnectSpiLoopbackRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<TestConnectSpiLoopbackRequest, ___E> for TestConnectSpiLoopbackRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, TestConnectSpiLoopbackRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, TestConnectSpiLoopbackRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestConnectSpiLoopbackRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestConnectSpiLoopbackRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<TestConnectSpiLoopbackRequest, ___E> for TestConnectSpiLoopbackRequest<T0>
impl<___E, T0> Encode<TestConnectSpiLoopbackRequest, ___E> for TestConnectSpiLoopbackRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestConnectSpiLoopbackRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestConnectSpiLoopbackRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TestConnectSpiLoopbackRequest> for TestConnectSpiLoopbackRequest
impl FromWire<TestConnectSpiLoopbackRequest> for TestConnectSpiLoopbackRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TestConnectSpiLoopbackRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<TestConnectSpiLoopbackRequest, Self>
Sourcefn from_wire(wire: TestConnectSpiLoopbackRequest) -> Self
fn from_wire(wire: TestConnectSpiLoopbackRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for TestConnectSpiLoopbackRequest
impl IntoNatural for TestConnectSpiLoopbackRequest
Sourcetype Natural = TestConnectSpiLoopbackRequest
type Natural = TestConnectSpiLoopbackRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TestConnectSpiLoopbackRequest
impl Wire for TestConnectSpiLoopbackRequest
Sourcetype Narrowed<'de> = TestConnectSpiLoopbackRequest
type Narrowed<'de> = TestConnectSpiLoopbackRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.